@@ -141,7 +141,7 @@ impl TraitImpls {
         let crate_def_map = db.crate_def_map(krate);
         impls.collect_def_map(db, &crate_def_map);
 
-        return Arc::new(impls);
+        Arc::new(impls)
     }
 
     pub(crate) fn trait_impls_in_block_query(
@@ -154,7 +154,7 @@ impl TraitImpls {
         let block_def_map = db.block_def_map(block)?;
         impls.collect_def_map(db, &block_def_map);
 
-        return Some(Arc::new(impls));
+        Some(Arc::new(impls))
     }
 
     fn collect_def_map(&mut self, db: &dyn HirDatabase, def_map: &DefMap) {
@@ -348,6 +348,7 @@ pub fn def_crates(
         }
         TyKind::Str => lang_item_crate!("str_alloc", "str"),
         TyKind::Slice(_) => lang_item_crate!("slice_alloc", "slice"),
+        TyKind::Array(..) => lang_item_crate!("array"),
         TyKind::Raw(Mutability::Not, _) => lang_item_crate!("const_ptr"),
         TyKind::Raw(Mutability::Mut, _) => lang_item_crate!("mut_ptr"),
         TyKind::Dyn(_) => {
@@ -422,7 +423,7 @@ pub fn iterate_method_candidates<T>(
     mut callback: impl FnMut(&Ty, AssocItemId) -> Option<T>,
 ) -> Option<T> {
     let mut slot = None;
-    iterate_method_candidates_impl(
+    iterate_method_candidates_dyn(
         ty,
         db,
         env,
@@ -440,7 +441,7 @@ pub fn iterate_method_candidates<T>(
     slot
 }
 
-fn iterate_method_candidates_impl(
+pub fn iterate_method_candidates_dyn(
     ty: &Canonical<Ty>,
     db: &dyn HirDatabase,
     env: Arc<TraitEnvironment>,
